@@ -537,11 +537,14 @@ class MuminDataset:
                 ['tweet', 'reply', 'user', 'claim', 'article', 'image'].
         '''
         # Compute the embeddings
-        self.nodes = self._embedder.embed_all(nodes=self.nodes,
-                                              nodes_to_embed=nodes_to_embed)
+        self.nodes, embeddings_added = self._embedder.embed_all(
+            nodes=self.nodes,
+            nodes_to_embed=nodes_to_embed
+        )
 
-        # Store dataset
-        self._dump_dataset()
+        # Store dataset if any embeddings were added
+        if embeddings_added:
+            self._dump_dataset()
 
         return self
 
